Команды управления моделью анализа сообщений — СпамоБорец: документация

### Navigation

- index
- next |
- previous |
- СпамоБорец: документация »
- API СпамоБорца »

# Команды управления моделью анализа сообщений

## Команда sf.model.classify

Классифицировать сообщение относительно модели анализа сообщений, получить результат классификации.

### Авторизация

Требуется, партнерская.

### Параметры

`partner`
  Partner партнерская авторизация

`domain`
  Domain домен, свойства которого мы хотим получить (необязательный)

`model`
  `string` имя свойства домена, содержащего модель анализа сообщений

`message`
  Message классифицируемое сообщение

`text_attribute`
  `string` имя атрибута сообщения, содержащего его текст (необязательный); если параметр пропущен, его значение считается равным `text`

### Результат

`marker`
  `string` результат классификации относительно модели: `"good"` - “сообщение хорошее” или `"bad"` - сообщение “плохое”

### Пример

#### JSON-RPC

    {"service":null,"method":"sf.model.classify","id":19,"params":[{"partner":null,"domain":"comment","model":"model","message":{"text":"Let's go to Amsterdam!"}}]}

    {"result": {"marker": "good"}, "id": 19}

## Команда sf.model.train

Обучить модель анализа сообщений на сообщении.

### Авторизация

Требуется, партнерская.

### Параметры

`partner`
  Partner партнерская авторизация

`domain`
  Domain домен, свойства которого мы хотим получить (необязательный)

`model`
  `string` имя свойства домена, содержащего модель анализа сообщений

`message`
  Message сообщение, на котором производится обучение

`text_attribute`
  `string` имя атрибута сообщения, содержащего его текст (необязательный); если параметр пропущен, его значение считается равным `text`

`marker`
  `string` каким является сообщение: `"good"` - “сообщение хорошее” или `"bad"` - сообщение “плохое”

### Результат

Нет.

### Пример

#### JSON-RPC

    {"service":null,"method":"sf.model.train","id":18,"params":[{"partner":null,"domain":"comment","model":"model","message":{"text":"Let's go to Amsterdam!"},"marker":"good"}]}

    {"result": {}, "id": 18}

### Navigation

- index
- next |
- previous |
- СпамоБорец: документация »
- API СпамоБорца »